pitchtools.HarmonicChromaticInterval
====================================

.. inheritance-diagram:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.cents

   .. note:: Inherited from :py:class:`pitchtools._Interval <abjad.tools.pitchtools._Interval._Interval._Interval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.harmonic_chromatic_interval_class

.. autoattribute:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.interval_class

   .. note:: Inherited from :py:class:`pitchtools._Interval <abjad.tools.pitchtools._Interval._Interval._Interval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.number

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.semitones

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__abs__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__add__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__eq__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__float__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__ge__

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__gt__

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__hash__

   .. note:: Inherited from :py:class:`pitchtools._Interval <abjad.tools.pitchtools._Interval._Interval._Interval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__int__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__le__

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__lt__

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__ne__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__repr__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__str__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicChromaticInterval.HarmonicChromaticInterval.HarmonicChromaticInterval.__sub__

   .. note:: Inherited from :py:class:`pitchtools._ChromaticInterval <abjad.tools.pitchtools._ChromaticInterval._ChromaticInterval._ChromaticInterval>`
